import 'package:flutter/material.dart';
import 'package:mobile_ui/mobile_ui.dart';

class SearchInput extends StatelessWidget {
  final String? hintText;
  final bool autofocus;
  final Function(String)? onSubmitted;
  final double marginFlactor;
  final TextEditingController? controller;

  const SearchInput({
    Key? key,
    this.hintText,
    this.onSubmitted,
    this.autofocus = false,
    this.marginFlactor = 1,
    this.controller,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);
    var inputBorder = OutlineInputBorder(
      borderRadius: BorderRadius.circular(5),
      borderSide: BorderSide(width: 0.5, color: theme.primaryColor),
    );

    return Container(
      margin: EdgeInsets.all(uiSpacing(marginFlactor)),
      child: TextField(
        cursorColor: theme.primaryColor,
        controller: controller,
        // onChanged: onChanged,
        onSubmitted: onSubmitted,
        autofocus: autofocus,
        keyboardType: TextInputType.text,
        textAlignVertical: TextAlignVertical.center,
        textAlign: TextAlign.start,
        decoration: InputDecoration(
          prefixIcon: Icon(Icons.search, color: Colors.black54),
          contentPadding: EdgeInsets.symmetric(horizontal: uiSpacing(1)),
          filled: false,
          border: inputBorder,
          fillColor: Colors.grey[100],
          enabledBorder: inputBorder,
          focusedBorder: inputBorder,
          hintText: hintText,
          hintStyle: TextStyle(
            color: Colors.black54,
          ),
        ),
      ),
    );
  }
}
