import 'dart:io';
import 'package:path_provider/path_provider.dart';

Future<String> getCacheDir([String? subDir]) async {
  var parentPath = (await getTemporaryDirectory()).path;
  return createSubDirIfNotExist(parentPath, subDir);
}

Future<String> getDownloadDir([String? subDir]) async {
  var parentPath = (await getDownloadsDirectory())!.path;
  return createSubDirIfNotExist(parentPath, subDir);
}

Future<String> createSubDirIfNotExist(String currentPath,
    [String? subDir]) async {
  if (subDir == null || subDir.isEmpty) {
    return currentPath;
  }
  var parentPath = currentPath;
  final dirs = subDir.split('/');
  for (final p in dirs) {
    final path = '$parentPath/$p';
    var dir = Directory(path);
    if (!dir.existsSync()) {
      await dir.create();
    }
    parentPath = path;
  }
  return parentPath;
}

Future<String> getStorageDir([String? subDir]) async {
  var parentPath = (await getExternalStorageDirectory())!.path;
  return createSubDirIfNotExist(parentPath, subDir);
}

Future<String> getDocumentsDir([String? subDir]) async {
  var parentPath = (await getApplicationDocumentsDirectory()).path;
  return createSubDirIfNotExist(parentPath, subDir);
}
